/*
 *   Copyright (C) 2020 CERN.
 *   Copyright (C) 2020 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */


@import "variables";
@import "../footer";

html,
body {
  font-family: 'Open Sans', sans-serif;
  color: #000;
  width: 100%;
  height: 100vh;
  display: flex;
  flex-direction: column;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: 'Oswald', 'Open Sans', sans-serif;
}

.search-header {
    background-image: @navbar_background_image;
    background-color: @navbar_background_color;

}

// Search
.search-aggregations {
    .ui.card {
        .content:first-child {
            color: #333;
            background-color: #f5f5f5;
            border-color: #ddd;
        }
    }
}
