{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- extends config.BASE_TEMPLATE %}

{%- block head_links %}
    {{ super() }}
    <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600|Oswald|Source+Code+Pro:400&amp;display=swap" rel="stylesheet">
{%- endblock head_links %}

{%- block css %}
    {{ webpack['theme.css']}}
    {{ webpack['invenio-app-rdm-search-theme.css']}}
{%-endblock %}

{%- block page_header %}
{%- include config.DEPOSITS_HEADER_TEMPLATE %}
{%- endblock page_header %}

{%- block page_body %}
<div class="ui container page_body" style="margin-top: 35px">
    <h1>Your deposits</h1>
    <div class="ui menu">
        <div class="ui action left icon input">
            <i class="search icon"></i>
            <input type="text" placeholder="Search">
            <button class="ui button">Search</button>
        </div>

        <div class="right menu">
            <div class="item">
                <a class="ui button primary" role="button" href="{{ url_for('invenio_app_rdm.deposits_create') }}">New Deposit</a>
            </div>
        </div>
    </div>

    <div class="ui text container">
        <img width="600" src="{{ url_for('static', filename='images/coming-soon.svg')}}" />
    </div>

</div>

{%- endblock page_body %}

{%- block javascript %}
    {{ super() }}
    {{ webpack['invenio-app-rdm-deposits-deposit-searchbar-js.js'] }}
{%- endblock %}
