{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- extends "semantic-ui/invenio_search_ui/search.html" %}

{%- block head_links %}
{{ super() }}
<link
  href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600|Oswald|Source+Code+Pro:400&amp;display=swap"
  rel="stylesheet">
{%- endblock head_links %}

{%- block css %}
{{ super() }}
{{ webpack['invenio-app-rdm-theme.css'] }}
{%-endblock %}

{% block javascript_searchapp_customization %}
{{ webpack['invenio-app-rdm-search-app-js.js'] }}
{% endblock javascript_searchapp_customization %}
